@@ -1,3 +1,4 @@
+import random
 import hashlib
 from datetime import datetime, timedelta
 from operator import or_
@@ -372,12 +373,19 @@ class ListEventsNode(ListNode):
             if order == "next_upcoming":
                 # Removed seconds and microseconds so we can cache the query better
                 now = datetime.now().replace(second=0, microsecond=0)
-                items = items.filter(start_dt__gt = now)
+                items = items.filter(start_dt__gt=now)
                 items = items.order_by("start_dt")
             elif order == "current_and_upcoming":
                 now = datetime.now().replace(second=0, microsecond=0)
                 items = items.filter(Q(start_dt__gt=now) | Q(end_dt__gt=now))
                 items = items.order_by("start_dt")
+            elif order == "current_and_upcoming_by_hour":
+                now = datetime.now().replace(second=0, microsecond=0)
+                today = datetime.now().replace(second=0, hour=0, minute=0, microsecond=0)
+                tomorrow = today + timedelta(days=1)
+                items = items.filter(Q(start_dt__lte=tomorrow) & Q(end_dt__gte=today)).extra(select={'hour': 'extract( hour from start_dt )'}).extra(select={'minute': 'extract( minute from start_dt )'}).extra(where=["extract( hour from start_dt ) >= %s"], params=[now.hour])
+                items = items.distinct()
+                items = items.order_by('hour', 'minute')
             else:
                 items = items.order_by(order)
 
