@@ -11,6 +11,7 @@ from django.contrib.contenttypes import generic
 from tendenci.core.categories.models import CategoryItem
 from tagging.fields import TagField
 from tendenci.core.base.fields import SlugField
+from tendenci.core.base.utils import now_localized
 from tendenci.core.perms.models import TendenciBaseModel
 from tendenci.core.perms.object_perms import ObjectPermission
 from tendenci.addons.jobs.managers import JobManager
@@ -79,12 +80,16 @@ class BaseJob(TendenciBaseModel):
     non_member_price = models.DecimalField(max_digits=20, decimal_places=2, blank=True, null=True)
     non_member_count = models.IntegerField(blank=True, null=True)
 
-    categories = generic.GenericRelation(CategoryItem,
-                                          object_id_field="object_id",
-                                          content_type_field="content_type")
-    perms = generic.GenericRelation(ObjectPermission,
-                                          object_id_field="object_id",
-                                          content_type_field="content_type")
+    categories = generic.GenericRelation(
+        CategoryItem,
+        object_id_field="object_id",
+        content_type_field="content_type"
+    )
+    perms = generic.GenericRelation(
+        ObjectPermission,
+        object_id_field="object_id",
+        content_type_field="content_type"
+    )
 
     objects = JobManager()
 
@@ -143,6 +148,8 @@ class BaseJob(TendenciBaseModel):
         """
         if not request.user.profile.is_superuser:
             self.status_detail = 'paid - pending approval'
+
+        self.activation_dt = now_localized()
         self.expiration_dt = self.activation_dt + timedelta(days=self.requested_duration)
         self.save()
 
