@@ -12,6 +12,9 @@ from django.http import HttpResponse
 from django.utils.html import escape
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
+from django.utils.translation import ugettext_lazy as _
+from django.contrib.admin import SimpleListFilter
+from django.utils.encoding import force_unicode
 
 from tendenci.addons.memberships.forms import MembershipTypeForm
 from tendenci.apps.user_groups.models import Group
@@ -24,7 +27,8 @@ from tendenci.addons.memberships.models import (Membership, MembershipDefault,
                                                 MembershipApp)
 from tendenci.addons.memberships.forms import (MembershipDefaultForm, AppForm,
                             NoticeForm, AppFieldForm, AppEntryForm,
-                            MembershipAppForm)
+                            MembershipAppForm,
+                            MembershipAppFieldAdminForm)
 from tendenci.addons.memberships.utils import (get_default_membership_fields,
                                                edit_app_update_corp_fields,
                                                get_selected_demographic_field_names)
@@ -434,11 +438,11 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
 
 class MembershipAppFieldAdmin(admin.TabularInline):
     model = MembershipAppField
-    fields = ('label', 'field_name', 'display', 'required', 'admin_only', 'order',)
+    fields = ('label', 'field_name', 'display', 'required', 'admin_only', 'position',)
     extra = 0
     can_delete = False
     verbose_name = 'Section Break'
-    ordering = ("order",)
+    ordering = ("position",)
     template = "memberships/admin/membershipapp/tabular.html"
 
 
@@ -830,8 +834,116 @@ class AppEntryAdmin(admin.ModelAdmin):
         self.list_display_links = (None, )
 
 
+class AppListFilter(SimpleListFilter):
+    title = _('Membership App')
+    parameter_name = 'membership_app_id'
+
+    def lookups(self, request, model_admin):
+        apps_list = MembershipApp.objects.filter(
+                        status=True,
+                        status_detail__in=['active', 'published']
+                        ).values_list('id', 'name'
+                        ).order_by('id')
+        return [(app_tuple[0], app_tuple[1]) for app_tuple in apps_list]
+
+    def queryset(self, request, queryset):
+        if self.value():
+            queryset = queryset.filter(
+                    membership_app_id=int(self.value()))
+        queryset = queryset.filter(display=True)
+        return queryset
+
+
+class MembershipAppField2Admin(admin.ModelAdmin):
+    model = MembershipAppField
+    list_display = ['label', 'field_name', 'display',
+              'required', 'admin_only', 'position',
+              ]
+
+    readonly_fields = ('membership_app', 'field_name')
+
+    list_editable = ['position']
+    ordering = ("position",)
+    list_filter = (AppListFilter,)
+    form = MembershipAppFieldAdminForm
+
+    class Media:
+        js = (
+            '%sjs/jquery-1.6.2.min.js' % settings.STATIC_URL,
+            'js/jquery-ui-1.8.17.custom.min.js',
+            '%sjs/admin/admin-list-reorder.js' % settings.STATIC_URL,
+        )
+
+    def get_fieldsets(self, request, obj=None):
+        extra_fields = ['description', 'help_text',
+                        'choices', 'default_value', 'css_class']
+        if obj:
+            if obj.field_name:
+                extra_fields.remove('description')
+            else:
+                extra_fields.remove('help_text')
+                extra_fields.remove('choices')
+                extra_fields.remove('default_value')
+        fields = ('membership_app', 'label', 'field_name', 'field_type',
+                    ('display', 'required', 'admin_only'),
+                             ) + tuple(extra_fields)
+
+        return ((None, {'fields': fields
+                        }),)
+
+    def get_object(self, request, object_id):
+        obj = super(MembershipAppField2Admin, self).get_object(request, object_id)
+
+        # assign default field_type
+        if obj:
+            if not obj.field_type:
+                if not obj.field_name:
+                    obj.field_type = 'section_break'
+                else:
+                    obj.field_type = MembershipAppField.get_default_field_type(obj.field_name)
+
+        return obj
+
+    def has_delete_permission(self, request, obj=None):
+        return False
+
+    def has_add_permission(self, request):
+        return False
+
+    def get_actions(self, request):
+        return None
+
+    def response_change(self, request, obj):
+        """
+        If the 'Save' button is clicked, redirect to fields list
+        with the selected app.
+        """
+        if "_save" in request.POST:
+            opts = obj._meta
+            verbose_name = opts.verbose_name
+            module_name = opts.module_name
+            if obj._deferred:
+                opts_ = opts.proxy_for_model._meta
+                verbose_name = opts_.verbose_name
+                module_name = opts_.module_name
+
+            msg = _('The %(name)s "%(obj)s" was changed successfully.') % {
+                        'name': force_unicode(verbose_name),
+                        'obj': force_unicode(obj)}
+            self.message_user(request, msg)
+            post_url = '%s?membership_app_id=%d' % (
+                            reverse('admin:%s_%s_changelist' %
+                                   (opts.app_label, module_name),
+                                   current_app=self.admin_site.name),
+                            obj.membership_app_id)
+            return HttpResponseRedirect(post_url)
+        else:
+            return super(MembershipAppField2Admin, self).response_change(request, obj)
+
+
 admin.site.register(MembershipDefault, MembershipDefaultAdmin)
 admin.site.register(MembershipApp, MembershipAppAdmin)
+admin.site.register(MembershipAppField, MembershipAppField2Admin)
 admin.site.register(MembershipType, MembershipTypeAdmin)
 admin.site.register(Notice, NoticeAdmin)
 #admin.site.register(App, AppAdmin)
